@@ -193,6 +193,7 @@ static PyObject *_PylibMC_RunSetCommand(PylibMC_Client *self, _PylibMC_SetComman
             /* Let store_val be NULL, thus triggering an error. */
         } else if (PyString_Check(val)) {
             store_val = val;
+            Py_INCREF(store_val);
         } else if (PyInt_Check(val)) {
             store_flags |= PYLIBMC_FLAG_INTEGER;
             store_val = PyObject_Str(val);
@@ -283,20 +284,19 @@ static PyObject *PylibMC_Client_delete(PylibMC_Client *self, PyObject *args) {
             && _PylibMC_CheckKeyStringAndSize(key, key_len)) {
         switch (rc = memcached_delete(self->mc, key, key_len, time)) {
             case MEMCACHED_SUCCESS:
-                retval = Py_True;
+                Py_RETURN_TRUE;
                 break;
             case MEMCACHED_FAILURE:
             case MEMCACHED_NOTFOUND:
             case MEMCACHED_NO_KEY_PROVIDED:
-                retval = Py_False;
+                Py_RETURN_FALSE;
                 break;
             default:
-                retval = PylibMC_ErrFromMemcached(self, "memcached_delete", rc);
+                return PylibMC_ErrFromMemcached(self, "memcached_delete", rc);
         }
     }
 
-    Py_XINCREF(retval);
-    return retval;
+    return NULL;
 }
 
 /* {{{ Increment & decrement */
@@ -315,7 +315,7 @@ static PyObject *_PylibMC_IncDec(PylibMC_Client *self, uint8_t dir,
         memcached_return (*incdec)(memcached_st *, const char *, size_t,
                 unsigned int, uint64_t *);
         incdec = (dir == PYLIBMC_INC) ? memcached_increment
-                                     : memcached_decrement;
+                                      : memcached_decrement;
         incdec(self->mc, key, key_len, delta, &result);
         retval = PyLong_FromUnsignedLong((unsigned long)result);
     }
@@ -372,10 +372,10 @@ static PyObject *PylibMC_Client_get_multi(PylibMC_Client *self, PyObject *args,
                 && (ckey = PyIter_Next(key_it)) != NULL) {
             PyObject *rkey;
 
-            if (!PyString_Check(ckey)) {
-                PyErr_SetString(PyExc_TypeError, "keys must be str");
+            if (!_PylibMC_CheckKey(ckey)) {
+                break;
             } else {
-                key_lens[i] = PyString_Size(ckey) + prefix_len;
+                key_lens[i] = PyString_GET_SIZE(ckey) + prefix_len;
                 if (prefix != NULL) {
                     rkey = PyString_FromFormat("%s%s",
                             prefix, PyString_AS_STRING(ckey));
@@ -389,6 +389,16 @@ static PyObject *PylibMC_Client_get_multi(PylibMC_Client *self, PyObject *args,
         }
         Py_DECREF(key_it);
 
+        if (PyErr_Occurred()) {
+            free(key_lens);
+            free(keys);
+            nkeys = i;
+            for (i = 0; i < nkeys; i++)
+                Py_DECREF(key_objs[i]);
+            free(key_objs);
+            return NULL;
+        }
+
         /* TODO Change this interface or at least provide an alternative that
          * returns some kind of iterable which fetches keys sequentially
          * instead of doing it all at once. The current way is grossly
