@@ -31,40 +31,40 @@
  * POSSIBILITY OF SUCH DAMAGE.
  */
 
-#ifndef __HANDMC_H__
-#define __HANDMC_H__
+#ifndef __PYLIBMC_H__
+#define __PYLIBMC_H__
 
 #include <Python.h>
 #include <libmemcached/memcached.h>
 
 /* Server types. */
-#define HANDMC_SERVER_TCP   (1 << 0)
-#define HANDMC_SERVER_UDP   (1 << 1)
-#define HANDMC_SERVER_UNIX  (1 << 2)
+#define PYLIBMC_SERVER_TCP   (1 << 0)
+#define PYLIBMC_SERVER_UDP   (1 << 1)
+#define PYLIBMC_SERVER_UNIX  (1 << 2)
 
 /* Key flags from python-memcache. */
-#define HANDMC_FLAG_NONE    0
-#define HANDMC_FLAG_PICKLE  (1 << 0)
-#define HANDMC_FLAG_INTEGER (1 << 1)
-#define HANDMC_FLAG_LONG    (1 << 2)
+#define PYLIBMC_FLAG_NONE    0
+#define PYLIBMC_FLAG_PICKLE  (1 << 0)
+#define PYLIBMC_FLAG_INTEGER (1 << 1)
+#define PYLIBMC_FLAG_LONG    (1 << 2)
 
-#define HANDMC_INC  (1 << 0)
-#define HANDMC_DEC  (1 << 1)
+#define PYLIBMC_INC  (1 << 0)
+#define PYLIBMC_DEC  (1 << 1)
 
-typedef memcached_return (*_HandMC_SetCommand)(memcached_st *, const char *,
+typedef memcached_return (*_PylibMC_SetCommand)(memcached_st *, const char *,
         size_t, const char *, size_t, time_t, uint32_t);
 
 /* {{{ Exceptions */
-static PyObject *HandMCExc_MemcachedError;
+static PyObject *PylibMCExc_MemcachedError;
 /* }}} */
 
 /* {{{ Behavior statics */
 typedef struct {
     int flag;
     char *name;
-} HandMC_Behavior;
+} PylibMC_Behavior;
 
-static HandMC_Behavior HandMC_behaviors[] = {
+static PylibMC_Behavior PylibMC_behaviors[] = {
     { MEMCACHED_BEHAVIOR_NO_BLOCK, "no block" },
     { MEMCACHED_BEHAVIOR_TCP_NODELAY, "tcp nodelay" },
     { MEMCACHED_BEHAVIOR_HASH, "hash" },
@@ -79,7 +79,7 @@ static HandMC_Behavior HandMC_behaviors[] = {
     { 0, NULL }
 };
 
-static HandMC_Behavior HandMC_hashers[] = {
+static PylibMC_Behavior PylibMC_hashers[] = {
     { MEMCACHED_HASH_DEFAULT, "default" },
     { MEMCACHED_HASH_MD5, "md5" },
     { MEMCACHED_HASH_CRC, "crc" },
@@ -90,7 +90,7 @@ static HandMC_Behavior HandMC_hashers[] = {
     { 0, NULL }
 };
 
-static HandMC_Behavior HandMC_distributions[] = {
+static PylibMC_Behavior PylibMC_distributions[] = {
     { MEMCACHED_DISTRIBUTION_MODULA, "modula" },
     { MEMCACHED_DISTRIBUTION_CONSISTENT, "consistent" },
     { MEMCACHED_DISTRIBUTION_CONSISTENT_KETAMA, "consistent_ketama" },
@@ -102,79 +102,80 @@ static HandMC_Behavior HandMC_distributions[] = {
 typedef struct {
     PyObject_HEAD
     memcached_st *mc;
-} HandMC_Client;
+} PylibMC_Client;
 
 /* {{{ Prototypes */
-static HandMC_Client *HandMC_ClientType_new(PyTypeObject *, PyObject *,
+static PylibMC_Client *PylibMC_ClientType_new(PyTypeObject *, PyObject *,
         PyObject *);
-static void HandMC_ClientType_dealloc(HandMC_Client *);
-static int HandMC_Client_init(HandMC_Client *, PyObject *, PyObject *);
-static PyObject *HandMC_Client_get(HandMC_Client *, PyObject *arg);
-static PyObject *HandMC_Client_set(HandMC_Client *, PyObject *, PyObject *);
-static PyObject *HandMC_Client_replace(HandMC_Client *, PyObject *,
+static void PylibMC_ClientType_dealloc(PylibMC_Client *);
+static int PylibMC_Client_init(PylibMC_Client *, PyObject *, PyObject *);
+static PyObject *PylibMC_Client_get(PylibMC_Client *, PyObject *arg);
+static PyObject *PylibMC_Client_set(PylibMC_Client *, PyObject *, PyObject *);
+static PyObject *PylibMC_Client_replace(PylibMC_Client *, PyObject *,
         PyObject *);
-static PyObject *HandMC_Client_add(HandMC_Client *, PyObject *, PyObject *);
-static PyObject *HandMC_Client_prepend(HandMC_Client *, PyObject *,
+static PyObject *PylibMC_Client_add(PylibMC_Client *, PyObject *, PyObject *);
+static PyObject *PylibMC_Client_prepend(PylibMC_Client *, PyObject *,
         PyObject *);
-static PyObject *HandMC_Client_append(HandMC_Client *, PyObject *, PyObject *);
-static PyObject *HandMC_Client_delete(HandMC_Client *, PyObject *);
-static PyObject *HandMC_Client_incr(HandMC_Client *, PyObject *);
-static PyObject *HandMC_Client_decr(HandMC_Client *, PyObject *);
-static PyObject *HandMC_Client_get_multi(HandMC_Client *, PyObject *, PyObject *);
-static PyObject *HandMC_Client_set_multi(HandMC_Client *, PyObject *, PyObject *);
-static PyObject *HandMC_Client_delete_multi(HandMC_Client *, PyObject *,
+static PyObject *PylibMC_Client_append(PylibMC_Client *, PyObject *, PyObject *);
+static PyObject *PylibMC_Client_delete(PylibMC_Client *, PyObject *);
+static PyObject *PylibMC_Client_incr(PylibMC_Client *, PyObject *);
+static PyObject *PylibMC_Client_decr(PylibMC_Client *, PyObject *);
+static PyObject *PylibMC_Client_get_multi(PylibMC_Client *, PyObject *, PyObject *);
+static PyObject *PylibMC_Client_set_multi(PylibMC_Client *, PyObject *, PyObject *);
+static PyObject *PylibMC_Client_delete_multi(PylibMC_Client *, PyObject *,
         PyObject *);
-static PyObject *HandMC_Client_get_behaviors(HandMC_Client *);
-static PyObject *HandMC_Client_set_behaviors(HandMC_Client *, PyObject *);
-static PyObject *HandMC_ErrFromMemcached(HandMC_Client *, const char *,
+static PyObject *PylibMC_Client_get_behaviors(PylibMC_Client *);
+static PyObject *PylibMC_Client_set_behaviors(PylibMC_Client *, PyObject *);
+static PyObject *PylibMC_ErrFromMemcached(PylibMC_Client *, const char *,
         memcached_return);
-static PyObject *_HandMC_Unpickle(const char *, size_t);
-static PyObject *_HandMC_Pickle(PyObject *);
-static int _HandMC_CheckKey(PyObject *);
+static PyObject *_PylibMC_Unpickle(const char *, size_t);
+static PyObject *_PylibMC_Pickle(PyObject *);
+static int _PylibMC_CheckKey(PyObject *);
+static int _PylibMC_CheckKeyStringAndSize(char *, size_t);
 /* }}} */
 
 /* {{{ Type's method table */
-static PyMethodDef HandMC_ClientType_methods[] = {
-    {"get", (PyCFunction)HandMC_Client_get, METH_O,
+static PyMethodDef PylibMC_ClientType_methods[] = {
+    {"get", (PyCFunction)PylibMC_Client_get, METH_O,
         "Retrieve a key from a memcached."},
-    {"set", (PyCFunction)HandMC_Client_set, METH_VARARGS|METH_KEYWORDS,
+    {"set", (PyCFunction)PylibMC_Client_set, METH_VARARGS|METH_KEYWORDS,
         "Set a key unconditionally."},
-    {"replace", (PyCFunction)HandMC_Client_replace, METH_VARARGS|METH_KEYWORDS,
+    {"replace", (PyCFunction)PylibMC_Client_replace, METH_VARARGS|METH_KEYWORDS,
         "Set a key only if it exists."},
-    {"add", (PyCFunction)HandMC_Client_add, METH_VARARGS|METH_KEYWORDS,
+    {"add", (PyCFunction)PylibMC_Client_add, METH_VARARGS|METH_KEYWORDS,
         "Set a key only if doesn't exist."},
-    {"prepend", (PyCFunction)HandMC_Client_prepend, METH_VARARGS|METH_KEYWORDS,
+    {"prepend", (PyCFunction)PylibMC_Client_prepend, METH_VARARGS|METH_KEYWORDS,
         "Prepend data to  a key."},
-    {"append", (PyCFunction)HandMC_Client_append, METH_VARARGS|METH_KEYWORDS,
+    {"append", (PyCFunction)PylibMC_Client_append, METH_VARARGS|METH_KEYWORDS,
         "Append data to a key."},
-    {"delete", (PyCFunction)HandMC_Client_delete, METH_VARARGS,
+    {"delete", (PyCFunction)PylibMC_Client_delete, METH_VARARGS,
         "Delete a key."},
-    {"incr", (PyCFunction)HandMC_Client_incr, METH_VARARGS,
+    {"incr", (PyCFunction)PylibMC_Client_incr, METH_VARARGS,
         "Increment a key by a delta."},
-    {"decr", (PyCFunction)HandMC_Client_decr, METH_VARARGS,
+    {"decr", (PyCFunction)PylibMC_Client_decr, METH_VARARGS,
         "Decrement a key by a delta."},
-    {"get_multi", (PyCFunction)HandMC_Client_get_multi,
+    {"get_multi", (PyCFunction)PylibMC_Client_get_multi,
         METH_VARARGS|METH_KEYWORDS, "Get multiple keys at once."},
-    {"set_multi", (PyCFunction)HandMC_Client_set_multi,
+    {"set_multi", (PyCFunction)PylibMC_Client_set_multi,
         METH_VARARGS|METH_KEYWORDS, "Set multiple keys at once."},
-    {"delete_multi", (PyCFunction)HandMC_Client_delete_multi,
+    {"delete_multi", (PyCFunction)PylibMC_Client_delete_multi,
         METH_VARARGS|METH_KEYWORDS, "Delete multiple keys at once."},
-    {"get_behaviors", (PyCFunction)HandMC_Client_get_behaviors, METH_NOARGS,
+    {"get_behaviors", (PyCFunction)PylibMC_Client_get_behaviors, METH_NOARGS,
         "Get behaviors dict."},
-    {"set_behaviors", (PyCFunction)HandMC_Client_set_behaviors, METH_O,
+    {"set_behaviors", (PyCFunction)PylibMC_Client_set_behaviors, METH_O,
         "Set behaviors dict."},
     {NULL}
 };
 /* }}} */
 
 /* {{{ Type def */
-static PyTypeObject HandMC_ClientType = {
+static PyTypeObject PylibMC_ClientType = {
     PyObject_HEAD_INIT(NULL)
     0,
     "client",
-    sizeof(HandMC_Client),
+    sizeof(PylibMC_Client),
     0,
-    (destructor)HandMC_ClientType_dealloc,
+    (destructor)PylibMC_ClientType_dealloc,
 
     0,
     0,
@@ -200,7 +201,7 @@ static PyTypeObject HandMC_ClientType = {
     0,
     0,
     0,
-    HandMC_ClientType_methods,
+    PylibMC_ClientType_methods,
     0,                                   
     0,                                   
     0,                                   
@@ -208,9 +209,9 @@ static PyTypeObject HandMC_ClientType = {
     0,                                   
     0,                                   
     0,                                   
-    (initproc)HandMC_Client_init,
+    (initproc)PylibMC_Client_init,
     0,                                   
-    (newfunc)HandMC_ClientType_new,              
+    (newfunc)PylibMC_ClientType_new,              
     0,          
     0,          
     0,          
@@ -222,4 +223,4 @@ static PyTypeObject HandMC_ClientType = {
 
 /* }}} */
 
-#endif /* def __HANDMC_H__ */
+#endif /* def __PYLIBMC_H__ */
